@@ -1,10 +1,14 @@
-# Copyrights 1999,2001-2015 by [Mark Overmeer].
+# Copyrights 1999-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution MIME::Types.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
 package MojoX::MIME::Types;
 use vars '$VERSION';
-$VERSION = '2.12';
+$VERSION = '2.19';
 
 use Mojo::Base -base;
 
@@ -23,7 +27,7 @@ sub new(%)
 sub mimeTypes() { shift->{MMT_mt} }
 
 
-sub types(;$)
+sub mapping(;$)
 {   my $self = shift;
     return $self->{MMT_ext} if $self->{MMT_ext};
 
@@ -33,12 +37,14 @@ sub types(;$)
     $self->{MMT_ext} = \%exttable;
 }
 
+*types = \&mapping;  # renamed in release 6.0
+
 #----------
 
 sub detect($$;$)
 {   my ($self, $accept, $prio) = @_;
     my $mt  = $self->mimeTypes;
-    my @ext = map $mt->type($_)->extensions,
+    my @ext = map $_->extensions, grep defined, map $mt->type($_),
         grep !/\*/, $mt->httpAccept($accept);
     \@ext;
 }
@@ -55,6 +61,25 @@ sub type($;$)
     $self;
 }
 
+
+sub file_type($) {
+	my ($self, $fn) = @_;
+	my $mt = $self->mimeTypes or return undef;
+	$mt->mimeTypeOf($fn);
+}
+
+
+sub content_type($;$) {
+	my ($self, $c, $opts) = @_;
+	my $headers = $c->res->headers;
+	return undef if $headers->content_type;
+
+	my $fn = $opts->{file} || $opts->{ext};
+
+	my $mt = $self->mimeTypes or return undef;
+	$headers->content_type($mt->mimeTypeOf($fn) || $mt->mimeTypeOf('txt'));
+}
+
 #---------------
 
 1;
